@@ -29,46 +29,13 @@ LOG = logging.getLogger(__name__)
 
 
 class SideEffect(base.Base):
-    """
-    This action has side effects and not enabled by default.
+    """This action has side effects and not enabled by default.
 
     See the provisioners documentation for further details.
-
-    .. program:: molecule side-effect
-
-    .. option:: molecule side-effect
-
-        Target the default scenario.
-
-    .. program:: molecule side-effect --scenario-name foo
-
-    .. option:: molecule side-effect --scenario-name foo
-
-        Targeting a specific scenario.
-
-    .. program:: molecule --debug side-effect
-
-    .. option:: molecule --debug side-effect
-
-        Executing with `debug`.
-
-    .. program:: molecule --base-config base.yml side-effect
-
-    .. option:: molecule --base-config base.yml side-effect
-
-        Executing with a `base-config`.
-
-    .. program:: molecule --env-file foo.yml side-effect
-
-    .. option:: molecule --env-file foo.yml side-effect
-
-        Load an env file to read variables from when rendering
-        molecule.yml.
     """
 
-    def execute(self):
-        """
-        Execute the actions necessary to perform a `molecule side-effect` and \
+    def execute(self, action_args=None):
+        """Execute the actions necessary to perform a `molecule side-effect` and \
         returns None.
 
         :return: None
@@ -78,7 +45,7 @@ class SideEffect(base.Base):
             LOG.warning(msg)
             return
 
-        self._config.provisioner.side_effect()
+        self._config.provisioner.side_effect(action_args)
 
 
 @base.click_command_ex()
@@ -87,9 +54,7 @@ class SideEffect(base.Base):
     "--scenario-name",
     "-s",
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help="Name of the scenario to target. ({})".format(
-        base.MOLECULE_DEFAULT_SCENARIO_NAME
-    ),
+    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
 def side_effect(ctx, scenario_name):  # pragma: no cover
     """Use the provisioner to perform side-effects to the instances."""
