@@ -515,32 +515,7 @@ class Ansible(base.Base):
                 self._config.ansible_collections_path: ":".join(collections_path_list),
                 "ANSIBLE_LIBRARY": ":".join(self._get_modules_directories()),
                 "ANSIBLE_FILTER_PLUGINS": ":".join(
-                    [
-                        self._get_filter_plugin_directory(),
-                        util.abs_path(
-                            os.path.join(
-                                self._config.scenario.ephemeral_directory,
-                                "plugins",
-                                "filter",
-                            ),
-                        ),
-                        util.abs_path(
-                            os.path.join(
-                                self._config.project_directory,
-                                "plugins",
-                                "filter",
-                            ),
-                        ),
-                        util.abs_path(
-                            os.path.join(
-                                os.path.expanduser("~"),
-                                ".ansible",
-                                "plugins",
-                                "filter",
-                            ),
-                        ),
-                        "/usr/share/ansible/plugins/filter",
-                    ],
+                    self._get_filter_plugins_directories(),
                 ),
             },
         )
@@ -904,6 +879,14 @@ class Ansible(base.Base):
             if not os.path.exists(source):
                 msg = f"The source path '{source}' does not exist."
                 util.sysexit_with_message(msg)
+            if os.path.exists(target):
+                if os.path.realpath(target) == os.path.realpath(source):
+                    msg = f"Required symlink {target} to {source} exist, skip creation"
+                    LOG.debug(msg)
+                    continue
+                msg = f"Required symlink {target} exist with another source"
+                LOG.debug(msg)
+                os.remove(target)
             msg = f"Inventory {source} linked to {target}"
             LOG.debug(msg)
             os.symlink(source, target)
@@ -1004,5 +987,44 @@ class Ansible(base.Base):
     def _get_filter_plugin_directory(self):
         return util.abs_path(os.path.join(self._get_plugin_directory(), "filter"))
 
+    def _get_filter_plugins_directories(self) -> list[str]:
+        """Return list of ansilbe filter plugins includes directories."""
+        paths: list[str | None] = []
+        if os.environ.get("ANSIBLE_FILTER_PLUGINS"):
+            paths = list(
+                map(util.abs_path, os.environ["ANSIBLE_FILTER_PLUGINS"].split(":")),
+            )
+
+        paths.extend(
+            [
+                self._get_filter_plugin_directory(),
+                util.abs_path(
+                    os.path.join(
+                        self._config.scenario.ephemeral_directory,
+                        "plugins",
+                        "filter",
+                    ),
+                ),
+                util.abs_path(
+                    os.path.join(
+                        self._config.project_directory,
+                        "plugins",
+                        "filter",
+                    ),
+                ),
+                util.abs_path(
+                    os.path.join(
+                        os.path.expanduser("~"),
+                        ".ansible",
+                        "plugins",
+                        "filter",
+                    ),
+                ),
+                "/usr/share/ansible/plugins/filter",
+            ],
+        )
+
+        return [path for path in paths if path is not None]
+
     def _absolute_path_for(self, env, key):
         return ":".join([self.abs_path(p) for p in env[key].split(":")])
